import 'hammerjs';
import { EventEmitter, Component, ChangeDetectionStrategy, ChangeDetectorRef, ElementRef, ContentChild, Output, Input, NgModule } from '@angular/core';
import * as _moment from 'moment';
import { IonicModule } from '@ionic/angular';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function CalendarDay() { }
if (false) {
    /** @type {?} */
    CalendarDay.prototype.number;
    /** @type {?} */
    CalendarDay.prototype.name;
    /** @type {?} */
    CalendarDay.prototype.date;
    /** @type {?} */
    CalendarDay.prototype.moment;
}
/**
 * @param {?} object
 * @return {?}
 */
function isCalendarDay(object) {
    return object && object.date && object.number && object.name && object.moment;
}
/**
 * @param {?} day1
 * @param {?} day2
 * @return {?}
 */
function compareCalendarDays(day1, day2) {
    return day1 && day2 && day1.moment && day2.moment && day1.moment.isSame(day2.moment);
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const moment = _moment;
class IonicHorizontalCalendarComponent {
    /**
     * @param {?} cdRef
     * @param {?} elementRef
     */
    constructor(cdRef, elementRef) {
        this.cdRef = cdRef;
        this.elementRef = elementRef;
        /**
         *
         */
        this.compareDays = compareCalendarDays;
        //////////////////////////////////////////// PRIVATES ////////////////////////////////////////////
        /**
         * Internal variable.
         */
        this.panExludedDelta = 0;
        /**
         * Internal variable
         */
        this.initialDateInternal = new Date();
        /////////////////////////////////////////////// OUTPUTS ////////////////////////////////////////////
        /**
         * Emits whenever the next day button is pressed.
         */
        this.nextDayClicked = new EventEmitter();
        /**
         * Emits whenever the prev day button is pressed.
         */
        this.prevDayClicked = new EventEmitter();
        /**
         * Emits the new selected day whenever it is changed.
         */
        this.daySelected = new EventEmitter();
        //////////////////////////////////////////// INPUTS ////////////////////////////////////////////
        /**
         * The amount of days to display at once.
         */
        this.dayCount = 7;
        /**
         * Callback to select days that should be excluded from selection.
         */
        this.daysToExclude = (/**
         * @param {?} day
         * @return {?}
         */
        (day) => day.date.getDay() === 6 || day.date.getDay() === 0 || moment(day.date).isBefore(this.minDate));
        /**
         * Scrolling sensivity when panning the days.
         */
        this.scrollSensivity = 1.0;
        /**
         * Make autoselection of the first day when component rendered
         */
        this.firstDayAutoSelected = false;
        /**
         * Display mode, can be daily or weekly
         */
        this.displayMode = 'daily';
    }
    //////////////////////////////////////////// INTERNAL VARIABLES ////////////////////////////////////////////
    /**
     * Array of days to render
     * @return {?}
     */
    get renderDays() {
        return Array(this.dayCount)
            .fill(this.dayCount)
            .map((/**
         * @param {?} _
         * @param {?} i
         * @return {?}
         */
        (_, i) => this.generateCalendarDay(this.firstDayRendered, i)));
    }
    /**
     * A string representing the localized month selected, for displaying purposes.
     * @return {?}
     */
    get monthSelected() {
        return this.localeData.months(this.firstDayRendered.moment, 'MMMM');
    }
    /**
     * @return {?}
     */
    get lastDayRendered() {
        return this.generateCalendarDay(this.firstDayRendered, this.dayCount - 1);
    }
    /**
     * Read-only, returns whether the calendar is allowed to scroll to the left.
     * @return {?}
     */
    get canMoveBack() {
        return !this.minDate || this.firstDayRendered.moment.isAfter(this.minDate, 'day');
    }
    /**
     * Read-only, returns whether the calendar is allowed to scroll to the right.
     * @return {?}
     */
    get canMoveForward() {
        return !this.maxDate || this.lastDayRendered.moment.isBefore(this.maxDate, 'day');
    }
    /**
     * Read-only, current selected locale for moment.
     * @private
     * @return {?}
     */
    get localeData() {
        return moment.localeData();
    }
    /**
     * Read-only, width in pixels of a step (pan delta required to actually scroll the calendar).
     * @private
     * @return {?}
     */
    get scrollStep() {
        /** @type {?} */
        const width = this.elementRef.nativeElement.clientWidth || 375;
        return ((width - 75) / this.dayCount) * this.scrollSensivity;
    }
    /**
     * moment's locale
     * @param {?} loc
     * @return {?}
     */
    set locale(loc) {
        moment.updateLocale(loc, {});
    }
    /**
     * @return {?}
     */
    get locale() {
        return moment.locale();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.displayMode === 'weekly') {
            /** @type {?} */
            let firstDayOfTheWeek = moment(this.initialDateInternal).weekday(0);
            this.firstDayRendered = this.generateCalendarDay(firstDayOfTheWeek);
        }
        else {
            this.firstDayRendered = this.generateCalendarDay(this.initialDateInternal);
        }
        if (this.firstDayAutoSelected) {
            /** @type {?} */
            let calendarDayToday = this.generateCalendarDay(this.initialDateInternal);
            this.selectDay(calendarDayToday);
        }
    }
    /**
     * Generate a CalendarDay object for a date, optionally offsetted by an arbitrary amount of days.
     * @param {?} date
     * @param {?=} daysToAdd
     * @return {?}
     */
    generateCalendarDay(date, daysToAdd) {
        /** @type {?} */
        let effectiveDate = isCalendarDay(date) ? moment(date.moment) : moment(date);
        // Apply days delta to date we're outputting
        if (daysToAdd > 0) {
            effectiveDate = effectiveDate.add(daysToAdd, 'days');
        }
        else if (daysToAdd < 0) {
            effectiveDate = effectiveDate.subtract(-daysToAdd, 'days');
        }
        return {
            number: effectiveDate.date(),
            name: this.localeData.weekdaysShort(effectiveDate),
            date: effectiveDate.toDate(),
            moment: effectiveDate
        };
    }
    /**
     * Generate a CalendarDay object for a date, optionally offsetted by an arbitrary amount of days.
     * @param {?} date
     * @param {?=} weekToAdd
     * @return {?}
     */
    generateCalendarWeekly(date, weekToAdd) {
        /** @type {?} */
        let effectiveDate = isCalendarDay(date) ? moment(date.moment) : moment(date);
        // Apply days delta to date we're outputting
        if (weekToAdd > 0) {
            effectiveDate = effectiveDate.add(weekToAdd, 'weeks');
        }
        else if (weekToAdd < 0) {
            effectiveDate = effectiveDate.subtract(-weekToAdd, 'weeks');
        }
        return {
            number: effectiveDate.date(),
            name: this.localeData.weekdaysShort(effectiveDate),
            date: effectiveDate.toDate(),
            moment: effectiveDate
        };
    }
    /**
     * Moves the calendar forward
     * @return {?}
     */
    next() {
        if (this.canMoveForward && this.displayMode === 'daily') {
            this.firstDayRendered = this.generateCalendarDay(this.firstDayRendered, 1);
            this.nextDayClicked.emit();
        }
        else if (this.canMoveForward && this.displayMode === 'weekly') {
            this.firstDayRendered = this.generateCalendarWeekly(this.firstDayRendered, 1);
            this.nextDayClicked.emit();
        }
    }
    /**
     * Moves the calendar backward
     * @return {?}
     */
    prev() {
        if (this.canMoveBack && this.displayMode === 'daily') {
            this.firstDayRendered = this.generateCalendarDay(this.firstDayRendered, -1);
            this.prevDayClicked.emit();
        }
        else if (this.canMoveBack && this.displayMode === 'weekly') {
            this.firstDayRendered = this.generateCalendarWeekly(this.firstDayRendered, -1);
            this.prevDayClicked.emit();
        }
    }
    /**
     * Set selected day
     * @param {?} day
     * @return {?}
     */
    selectDay(day) {
        this.currentSelectedDay = day;
        this.daySelected.emit(day);
    }
    /**
     * Hadler for when swiping ends.
     * @return {?}
     */
    swipeEnd() {
        this.panExludedDelta = 0;
    }
    /**
     * Handler for when swiping is active and changes offset.
     * @param {?} event
     * @return {?}
     */
    swipeMove(event) {
        if (event.deltaX - this.panExludedDelta > this.scrollStep) {
            this.prev();
            this.panExludedDelta += this.scrollStep;
        }
        else if (event.deltaX - this.panExludedDelta < -this.scrollStep) {
            this.next();
            this.panExludedDelta -= this.scrollStep;
        }
    }
}
IonicHorizontalCalendarComponent.decorators = [
    { type: Component, args: [{
                selector: 'ionic-horizontal-calendar',
                template: "<div class=\"top-wrapper\">\r\n  <div class=\"header\" *ngIf=\"content\">\r\n    <ng-container *ngTemplateOutlet=\"headerTemplate\"></ng-container>\r\n  </div>\r\n\r\n  <p class=\"month-text\">{{ monthSelected }}</p>\r\n\r\n  <div class=\"days-wrapper\">\r\n    <ion-icon\r\n      name=\"arrow-back\"\r\n      class=\"arrow\"\r\n      (click)=\"prev()\"\r\n      [class.arrow-disabled]=\"!canMoveBack\"\r\n    ></ion-icon>\r\n    <div class=\"inline-calendar\" (panmove)=\"swipeMove($event)\" (panend)=\"swipeEnd()\">\r\n      <div\r\n        *ngFor=\"let dayOffset of renderDays\"\r\n        class=\"day-of-week-wrapper\"\r\n        (click)=\"!daysToExclude(dayOffset) && selectDay(dayOffset)\"\r\n        [class.day-unavailable]=\"daysToExclude(dayOffset)\"\r\n        [class.day-selected]=\"compareDays(currentSelectedDay, dayOffset)\"\r\n      >\r\n        <ion-label class=\"number-date\" [class.number-day-unavailable]=\"daysToExclude(dayOffset)\">{{ dayOffset.number }}</ion-label>\r\n        <ion-label class=\"text-date\" [class.text-day-unavailable]=\"daysToExclude(dayOffset)\">{{ dayOffset.name | titlecase }}</ion-label>\r\n      </div>\r\n    </div>\r\n    <ion-icon\r\n      name=\"arrow-forward\"\r\n      class=\"arrow\"\r\n      (click)=\"next()\"\r\n      [class.arrow-disabled]=\"!canMoveForward\"\r\n    ></ion-icon>\r\n  </div>\r\n</div>\r\n\r\n<ng-template #headerTemplate>\r\n  <ng-content select=\"[header]\"></ng-content>\r\n</ng-template>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".top-wrapper{background-color:var(--background-color-calendar,#fcf8f8);border-bottom:var(--border-botto-calendar,1px solid gray);padding-top:var(--padding-top-calendar,10px)}.top-wrapper .header{margin:var(--margin-header,0);margin-bottom:var(--margin-bottom-header,10px);text-align:var(--text-align-header,center);display:var(--display-header,flex);align-items:var(--align-items-header,center);justify-content:var(--justify-content-header,center);font-size:var(--font-size-header,20px)}.top-wrapper .month-text{color:var(--color-month,#979797);margin:var(--margin-month,0);text-align:var(--text-align-month,center);font-size:var(--font-size-month,18px)}.top-wrapper .days-wrapper{width:var(--width-days,100%);height:var(--height-days,60px);display:flex;flex-direction:row;align-items:center}.top-wrapper .days-wrapper .arrow{width:var(--width-arrow,10%)}.top-wrapper .days-wrapper .arrow-disabled{opacity:var(--opacity-disabled-arrow,.3)}.top-wrapper .days-wrapper .inline-calendar{flex:1;display:flex;flex-direction:row;height:100%}.top-wrapper .days-wrapper .inline-calendar .day-unavailable{background-color:var(--background-color-day-unavailable,#ffebeb)}.top-wrapper .days-wrapper .inline-calendar .day-selected{border-bottom:var(--border-bottom-day-selected,3px solid red);background-color:var(--background-color-day-selected,#fcf8f8)}.top-wrapper .days-wrapper .inline-calendar .day-of-week-wrapper{flex:1;display:flex;flex-direction:column;justify-content:center}.top-wrapper .days-wrapper .inline-calendar .day-of-week-wrapper .number-date{font-size:var(--font-size-number-date,25px);text-align:var(--text-align-number-date,center);color:var(--color-number-date,#000)}.top-wrapper .days-wrapper .inline-calendar .day-of-week-wrapper .text-date{font-size:var(--font-size-text-date,12px);color:var(--color-text-date,#979797);text-align:var(--text-align-text-date,center)}.top-wrapper .days-wrapper .inline-calendar .day-of-week-wrapper .number-day-unavailable{color:var(--color-number-day-unavailable,#000)}.top-wrapper .days-wrapper .inline-calendar .day-of-week-wrapper .text-day-unavailable{color:var(--color-text-day-unavailable,#000)}"]
            }] }
];
/** @nocollapse */
IonicHorizontalCalendarComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef }
];
IonicHorizontalCalendarComponent.propDecorators = {
    content: [{ type: ContentChild, args: ['header', { static: true },] }],
    nextDayClicked: [{ type: Output }],
    prevDayClicked: [{ type: Output }],
    daySelected: [{ type: Output }],
    dayCount: [{ type: Input }],
    daysToExclude: [{ type: Input }],
    minDate: [{ type: Input }],
    maxDate: [{ type: Input }],
    scrollSensivity: [{ type: Input }],
    locale: [{ type: Input }],
    firstDayAutoSelected: [{ type: Input }],
    displayMode: [{ type: Input }]
};
if (false) {
    /**
     * The selected CalendarDay, for displaying purposes.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.currentSelectedDay;
    /**
     * First date to render, used to build displayedDays.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.firstDayRendered;
    /**
     * The projected header, if any
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.content;
    /**
     *
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.compareDays;
    /**
     * Internal variable.
     * @type {?}
     * @private
     */
    IonicHorizontalCalendarComponent.prototype.panExludedDelta;
    /**
     * Internal variable
     * @type {?}
     * @private
     */
    IonicHorizontalCalendarComponent.prototype.initialDateInternal;
    /**
     * Emits whenever the next day button is pressed.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.nextDayClicked;
    /**
     * Emits whenever the prev day button is pressed.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.prevDayClicked;
    /**
     * Emits the new selected day whenever it is changed.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.daySelected;
    /**
     * The amount of days to display at once.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.dayCount;
    /**
     * Callback to select days that should be excluded from selection.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.daysToExclude;
    /**
     * Min date allowed.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.minDate;
    /**
     * Max date allowed.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.maxDate;
    /**
     * Scrolling sensivity when panning the days.
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.scrollSensivity;
    /**
     * Make autoselection of the first day when component rendered
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.firstDayAutoSelected;
    /**
     * Display mode, can be daily or weekly
     * @type {?}
     */
    IonicHorizontalCalendarComponent.prototype.displayMode;
    /**
     * @type {?}
     * @private
     */
    IonicHorizontalCalendarComponent.prototype.cdRef;
    /**
     * @type {?}
     * @private
     */
    IonicHorizontalCalendarComponent.prototype.elementRef;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IonicHorizontalCalendarModule {
}
IonicHorizontalCalendarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [IonicHorizontalCalendarComponent],
                imports: [CommonModule, IonicModule.forRoot()],
                exports: [IonicHorizontalCalendarComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { IonicHorizontalCalendarComponent, IonicHorizontalCalendarModule };
//# sourceMappingURL=ionic-horizontal-calendar.js.map
