import { EventEmitter, ChangeDetectorRef, ElementRef, OnInit } from '@angular/core';
import * as _moment from 'moment';
import { CalendarDay, compareCalendarDays } from './calendar-day';
export declare class IonicHorizontalCalendarComponent implements OnInit {
    private cdRef;
    private elementRef;
    /** Array of days to render */
    readonly renderDays: CalendarDay[];
    /** A string representing the localized month selected, for displaying purposes. */
    readonly monthSelected: string;
    /** The selected CalendarDay, for displaying purposes. */
    currentSelectedDay: CalendarDay;
    /** First date to render, used to build displayedDays. */
    firstDayRendered: CalendarDay;
    readonly lastDayRendered: CalendarDay;
    /** Read-only, returns whether the calendar is allowed to scroll to the left. */
    readonly canMoveBack: boolean;
    /** Read-only, returns whether the calendar is allowed to scroll to the right. */
    readonly canMoveForward: boolean;
    /** The projected header, if any */
    content: any;
    /**  */
    compareDays: typeof compareCalendarDays;
    /** Internal variable.  */
    private panExludedDelta;
    /** Internal variable */
    private initialDateInternal;
    /** Read-only, current selected locale for moment. */
    private readonly localeData;
    /** Read-only, width in pixels of a step (pan delta required to actually scroll the calendar). */
    private readonly scrollStep;
    /** Emits whenever the next day button is pressed. */
    nextDayClicked: EventEmitter<any>;
    /** Emits whenever the prev day button is pressed. */
    prevDayClicked: EventEmitter<any>;
    /** Emits the new selected day whenever it is changed. */
    daySelected: EventEmitter<CalendarDay>;
    /** The amount of days to display at once. */
    dayCount: number;
    /** Callback to select days that should be excluded from selection. */
    daysToExclude: (day: CalendarDay) => boolean;
    /** Min date allowed. */
    minDate: _moment.MomentInput;
    /** Max date allowed. */
    maxDate: _moment.MomentInput;
    /** Scrolling sensivity when panning the days. */
    scrollSensivity: number;
    /** moment's locale */
    locale: string;
    /** Make autoselection of the first day when component rendered */
    firstDayAutoSelected: boolean;
    /** Display mode, can be daily or weekly */
    displayMode: 'daily' | 'weekly';
    constructor(cdRef: ChangeDetectorRef, elementRef: ElementRef);
    ngOnInit(): void;
    /** Generate a CalendarDay object for a date, optionally offsetted by an arbitrary amount of days. */
    generateCalendarDay(date: _moment.MomentInput | CalendarDay, daysToAdd?: number): CalendarDay;
    /** Generate a CalendarDay object for a date, optionally offsetted by an arbitrary amount of days. */
    generateCalendarWeekly(date: _moment.MomentInput | CalendarDay, weekToAdd?: number): CalendarDay;
    /** Moves the calendar forward */
    next(): void;
    /** Moves the calendar backward */
    prev(): void;
    /** Set selected day */
    selectDay(day: CalendarDay): void;
    /** Hadler for when swiping ends. */
    swipeEnd(): void;
    /** Handler for when swiping is active and changes offset. */
    swipeMove(event: any): void;
}
